==> syncthingtray-0.10.2.tar.gz: syncthingtray-0.10.2/fileitemactionplugin/translations/syncthingfileitemaction_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>SyncthingDirActions</name>
    <message>
        <location filename="../syncthingdiractions.cpp" line="31"/>
        <source>Status: not available anymore</source>
        <translation>Status: nicht mehr verfügbar</translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="40"/>
        <source>Directory info for %1</source>
        <translation>Verzeichnisinfo für %1</translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="41"/>
        <source>Status: </source>
        <translation>Status: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="67"/>
        <source>Global: </source>
        <translation>Global: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="68"/>
        <source>Local: </source>
        <translation>Lokal: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="69"/>
        <source>Last scan time: </source>
        <translation>Letzter Scan: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="70"/>
        <source>Rescan interval: %1 seconds</source>
        <translation>Scanintervall: %1 Sekunden</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdiractions.cpp" line="75"/>
        <source>%1 item(s) out-of-sync</source>
        <translation>
            <numerusform>%1 Element nicht synchronisiert</numerusform>
            <numerusform>%1 Elemente nicht synchronisiert</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SyncthingFileItemAction</name>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="111"/>
        <source>Rescan selected items</source>
        <translation>Auswahl neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="129"/>
        <source>Rescan selected directories</source>
        <translation>Ausgewählte Verzeichnisse neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="152"/>
        <source>Resume selected directories</source>
        <translation>Ausgewählte verzeichnisse fortsetzen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="113"/>
        <location filename="../syncthingfileitemaction.cpp" line="129"/>
        <location filename="../syncthingfileitemaction.cpp" line="169"/>
        <source>Rescan &quot;%1&quot;</source>
        <translation>&quot;%1&quot; neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="155"/>
        <source>Pause selected directories</source>
        <translation>Ausgewählte Verzeichnisse pausieren</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="169"/>
        <source>Rescan containing directories</source>
        <translation>Beinhaltendes Verzeichnis neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="192"/>
        <source>Resume containing directories</source>
        <translation>Beinhaltendes Verzeichnis fortsetzen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="152"/>
        <location filename="../syncthingfileitemaction.cpp" line="192"/>
        <source>Resume &quot;%1&quot;</source>
        <translation>&quot;%1&quot; fortsetzen (in &quot;%1&quot;)</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="196"/>
        <source>Pause containing directories</source>
        <translation>Beinhaltendes Verzeichnis pausieren</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="155"/>
        <location filename="../syncthingfileitemaction.cpp" line="196"/>
        <source>Pause &quot;%1&quot;</source>
        <translation>&quot;%1&quot; pausieren (in &quot;%1&quot;)</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="235"/>
        <source>Select Syncthing config ...</source>
        <translation>Syncthing-Konfiguration wählen ...</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="240"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
</context>
<context>
    <name>SyncthingFileItemActionStaticData</name>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="85"/>
        <source>Syncthing connection error</source>
        <translation>Fehler beim Verbinden mit Syncthing</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="105"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="113"/>
        <source>Select Syncthing config file</source>
        <translation>Syncthing-Konfigurationsdatei auswählen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="134"/>
        <source>Syncthing config file can not be automatically located</source>
        <translation>Syncthing-Konfigurationsdatei kann nicht automatisch gefunden werden</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="141"/>
        <source>Unable to load Syncthing config from &quot;%1&quot;</source>
        <translation>Fehler beim Laden der Syncthing-Konfiguration von &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="150"/>
        <source>Syncthing config from &quot;%1&quot; does not contain GUI address.</source>
        <translation>Die Syncthing-Konfiguration &quot;%1&quot; beinhaltet keine GUI-Adresse.</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="162"/>
        <source>Enter API key</source>
        <translation>API-Schlüssel eingeben</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="162"/>
        <source>The selected config file does not contain an API key. Please enter the API key manually:</source>
        <translation>Die gewählte Konfiguration enthält keinen API-Schlüssel. Gib den API-Schlüssel manuell ein:</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="164"/>
        <source>No API key supplied for &quot;%1&quot;.</source>
        <translation>Kein API-Schlüssel für die Konfiguration &quot;%1&quot; angegeben.</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="123"/>
        <source>(still using config from &quot;%1&quot;)</source>
        <translation>(verwende weiterhin &quot;%1&quot;)</translation>
    </message>
</context>
<context>
    <name>SyncthingMenuAction</name>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="68"/>
        <source>Syncthing</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="79"/>
        <source>Syncthing - connecting</source>
        <translation>Syncthing - verbinde</translation>
    </message>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="81"/>
        <source>Syncthing - not connected</source>
        <translation>Syncthing - nicht verbunden</translation>
    </message>
</context>
</TS>

==> syncthingtray_1.2.2.orig.tar.gz: syncthingtray-1.2.2/fileitemactionplugin/translations/syncthingfileitemaction_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>SyncthingDirActions</name>
    <message>
        <location filename="../syncthingdiractions.cpp" line="34"/>
        <source>Status: not available anymore</source>
        <translation>Status: nicht mehr verfügbar</translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="43"/>
        <source>Directory info for %1</source>
        <translation>Verzeichnisinfo für %1</translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="44"/>
        <source>Status: </source>
        <translation>Status: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="73"/>
        <source>Global: </source>
        <translation>Global: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="74"/>
        <source>Local: </source>
        <translation>Lokal: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="75"/>
        <source>Last scan time: </source>
        <translation>Letzter Scan: </translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="76"/>
        <source>Rescan interval: %1 seconds</source>
        <translation>Scanintervall: %1 Sekunden</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdiractions.cpp" line="81"/>
        <source>%1 item(s) out-of-sync</source>
        <translation>
            <numerusform>%1 Element nicht synchronisiert</numerusform>
            <numerusform>%1 Elemente nicht synchronisiert</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SyncthingFileItemAction</name>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="153"/>
        <source>Rescan selected items</source>
        <translation>Auswahl neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="172"/>
        <source>Rescan selected directories</source>
        <translation>Ausgewählte Verzeichnisse neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="185"/>
        <source>Resume selected directories</source>
        <translation>Ausgewählte verzeichnisse fortsetzen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="155"/>
        <location filename="../syncthingfileitemaction.cpp" line="172"/>
        <location filename="../syncthingfileitemaction.cpp" line="203"/>
        <source>Rescan &quot;%1&quot;</source>
        <translation>&quot;%1&quot; neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="188"/>
        <source>Pause selected directories</source>
        <translation>Ausgewählte Verzeichnisse pausieren</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="203"/>
        <source>Rescan containing directories</source>
        <translation>Beinhaltendes Verzeichnis neu scannen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="216"/>
        <source>Resume containing directories</source>
        <translation>Beinhaltendes Verzeichnis fortsetzen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="185"/>
        <location filename="../syncthingfileitemaction.cpp" line="216"/>
        <source>Resume &quot;%1&quot;</source>
        <translation>&quot;%1&quot; fortsetzen (in &quot;%1&quot;)</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="220"/>
        <source>Pause containing directories</source>
        <translation>Beinhaltendes Verzeichnis pausieren</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="188"/>
        <location filename="../syncthingfileitemaction.cpp" line="220"/>
        <source>Pause &quot;%1&quot;</source>
        <translation>&quot;%1&quot; pausieren (in &quot;%1&quot;)</translation>
    </message>
    <message>
        <source>Use bright custom colors</source>
        <translation type="vanished">Helle Farben verwenden</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="260"/>
        <source>Select Syncthing config ...</source>
        <translation>Syncthing-Konfiguration wählen ...</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="265"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
</context>
<context>
    <name>SyncthingFileItemActionStaticData</name>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="84"/>
        <source>Syncthing connection error</source>
        <translation>Fehler beim Verbinden mit Syncthing</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="108"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="116"/>
        <source>Select Syncthing config file</source>
        <translation>Syncthing-Konfigurationsdatei auswählen</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="142"/>
        <source>Syncthing config file can not be automatically located</source>
        <translation>Syncthing-Konfigurationsdatei kann nicht automatisch gefunden werden</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="149"/>
        <source>Unable to load Syncthing config from &quot;%1&quot;</source>
        <translation>Fehler beim Laden der Syncthing-Konfiguration von &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="158"/>
        <source>Syncthing config from &quot;%1&quot; does not contain GUI address.</source>
        <translation>Die Syncthing-Konfiguration &quot;%1&quot; beinhaltet keine GUI-Adresse.</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="170"/>
        <source>Enter API key</source>
        <translation>API-Schlüssel eingeben</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="170"/>
        <source>The selected config file does not contain an API key. Please enter the API key manually:</source>
        <translation>Die gewählte Konfiguration enthält keinen API-Schlüssel. Gib den API-Schlüssel manuell ein:</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="172"/>
        <source>No API key supplied for &quot;%1&quot;.</source>
        <translation>Kein API-Schlüssel für die Konfiguration &quot;%1&quot; angegeben.</translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="131"/>
        <source>(still using config from &quot;%1&quot;)</source>
        <translation>(verwende weiterhin &quot;%1&quot;)</translation>
    </message>
</context>
<context>
    <name>SyncthingMenuAction</name>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="68"/>
        <source>Syncthing</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="79"/>
        <source>Syncthing - connecting</source>
        <translation>Syncthing - verbinde</translation>
    </message>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="81"/>
        <source>Syncthing - not connected</source>
        <translation>Syncthing - nicht verbunden</translation>
    </message>
</context>
</TS>
